@@ -45,7 +45,7 @@ our @EXPORT = qw(
    cqptokens tokenize
 );
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 our $abrev;
 
@@ -203,7 +203,7 @@ dos tomos.
 
 =item tokeniza
 
-Usa um algortmo desenvolvido no Plo de Oslo da Linguateca. Retorna
+Usa um algoritmo desenvolvido no Plo de Oslo da Linguateca. Retorna
 um tomo por linha em contexto escalar, e uma lista de tomos em
 contexto de lista.
 
@@ -214,6 +214,11 @@ separador de frases (ou de registo) usando a opo 'irs':
 
    cqptokens( { irs => "\n\n" }, "file" );
 
+outras opes:
+
+   cqptokens( { enc => ":utf8"}, "file" ); # enc => charset
+                                           # outenc => charset
+
 =back
 
 =cut
@@ -243,7 +248,9 @@ sub tokenize{
 }
 
 sub cqptokens{        ## 
-  my %opt = ( irs => ">"); # irs => INPUT RECORD SEPARATOR
+  my %opt = ( irs => ">"); # irs => INPUT RECORD SEPARATOR; 
+                           # enc => charset
+                           # outenc => charset
   if(ref($_[0]) eq "HASH"){ %opt = (%opt , %{shift(@_)});}
   my $file = shift || "-";
 
@@ -251,6 +258,8 @@ sub cqptokens{        ##
   my %tag=();
   my ($a,$b);
   open(F,"$file");
+  binmode(F,$opt{enc})         if $opt{enc};
+  binmode(STDOUT,$opt{outenc}) if $opt{outenc};
   while(<F>) {
     if(/<(\w+)(.*?)>/){
       ($a, $b) = ($1,$2);
